import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
import copy

def clean(input_array):
    """
    Cleans the input array by replacing values outside the range (-1, 1) with the last valid value.

    Parameters:
        input_array (np.array): Array of values to be cleaned.

    Returns:
        np.array: Cleaned array with replaced values.
    """
    cleaned_array = []
    last_valid_value = None
    for value in input_array:
        if -1 < value < 1:
            cleaned_array.append(value)
            last_valid_value = value
        else:
            cleaned_array.append(last_valid_value)
    return np.array(cleaned_array)

# Load data from files
df_symmetric_cell_cycling = pd.read_excel('LSN_0.1mA cycling.xlsx')
df_LSN_LZC = pd.read_excel('LSN_LZC_LSN_0.1mA_30min.xlsx')
df_LZC = pd.read_csv('LZC_Li sym.csv')

# Create subplots
fig, axs = plt.subplots(2, 1, figsize=(3.25, 3.25 * 2 / 3 * 2), dpi=400)

# Plot for symmetric cell cycling data
cleaned_voltage = clean(df_symmetric_cell_cycling['V of VRL_Li_Li_SN.028'])
axs[0].plot(df_symmetric_cell_cycling['X'], cleaned_voltage, color='cornflowerblue')
axs[0].set_ylim(-0.7, 0.7)
axs[0].set_xlim(0, 1000)
axs[0].set_xlabel('Time (h)', size=12)
axs[0].set_ylabel('Voltage (V)', size=12)

# Plot for LSN and LZC data
axs[1].plot(df_LSN_LZC['X'][:-600], df_LSN_LZC['V of VRL_LSN_LZC_100uA_30min.026'][:-600], color='cornflowerblue')
axs[1].plot(df_LZC[df_LZC.columns[0]], df_LZC[df_LZC.columns[1]], color='lightslategray')
axs[1].set_ylim(-0.7, 0.7)
axs[1].set_xlim(0, 200)
axs[1].set_xlabel('Time (h)', size=12)
axs[1].set_ylabel('Voltage (V)', size=12)

# Customize tick parameters
for ax in axs:
    ax.tick_params(axis='both', direction='in')

# Adjust layout
plt.subplots_adjust(hspace=0.4)

# Save or show the plot
plt.show()